@@ -1,7 +1,7 @@
-from cloudam_stream.core.actors import SinkActor
-from cloudam_stream.core.constants import config
+from core.actors import SinkActor
+from core.constants import config
 
-from cloudam_stream.core.ports.inputports import TextInputPort
+from core.ports.inputports import TextInputPort
 
 
 class MySinkActor(SinkActor):
@@ -15,7 +15,7 @@ class MySinkActor(SinkActor):
 
     def write(self, item, port):
         print("------running sink actor")
-        self.file.write(item)
+        self.file.write(item.serialize())
 
     def end(self):
         print("------stop sink actor")
